# icartt

``icartt`` is an ICARTT format reader and writer

## Documentation

Please have a look at docs/source/usage.rst for usage examples. Full documentation is in preparation.

## Contributing

We are looking forward to receiving your [new issue report](https://mbees.med.uni-augsburg.de/gitlab/mbees/icartt_pypackage/-/issues/new).

If you'd like to contribute source code directly, please [create a fork](https://mbees.med.uni-augsburg.de/gitlab/mbees/icartt_pypackage),
make your changes and then [submit a merge request](https://mbees.med.uni-augsburg.de/gitlab/mbees/icartt_pypackage/-/merge_requests/new) to the original project.


## Installation of the development version

Clone this repository / or your fork and install. We use [poetry](https://python-poetry.org/) for packaging, which needs to be installed.

```
git clone https://mbees.med.uni-augsburg.de/gitlab/mbees/icartt_pypackage.git or <URL of your fork>
cd icartt_pypackage
poetry install
poetry shell
```

# Changelog

## 2.0.0 (2022-04-28)

- Compatible with ICARTT v2 standard
- Formats 1001 and 2110
- Complete internal overhaul

## 1.0.0 (2017-12-19)

- Peer-reviewed version to be published in Knote et al., GMD

## 0.1.0 (2017-08-12)

- Initial release
